@@ -16,7 +16,7 @@ if TYPE_CHECKING:
     from tox.pytest import ToxProjectCreator
 
 
-@pytest.mark.integration()
+@pytest.mark.integration
 def test_setuptools_package(
     tox_project: ToxProjectCreator,
     demo_pkg_setuptools: Path,
@@ -51,5 +51,5 @@ def test_setuptools_package(
     assert len(py_messages) == 5, "\n".join(py_messages)  # 1 install wheel + 3 command + 1 final report
 
     package_messages = [i for i in result if ".pkg: " in i]
-    # 1 optional hooks + 1 install requires + 1 build requires + 1 build meta + 1 build isolated
-    assert len(package_messages) == 5, "\n".join(package_messages)
+    # 1 optional hooks + 1 install requires + 1 build meta + 1 build isolated
+    assert len(package_messages) == 4, "\n".join(package_messages)
